%% Bewegungsgleichungen des Doppelpendels, A14, Herleitung in MATLAB
% Derive the Equations of motion for the double pendulum (MBS)

syms l1 l2 t_ m1 m2 g
syms alpha1 Dalpha1 D2alpha1 alpha2 Dalpha2 D2alpha2

% Vektor der verallgemeinerten Koordinaten
y   = [alpha1;alpha2];
yd  = [Dalpha1;Dalpha2];
ydd = [D2alpha1;D2alpha2];

% Ortsvektoren definieren
r1 = [ 0;
       l1*sin(alpha1);
      -l1*cos(alpha1)];
r2 = [ 0;
       l1*sin(alpha1)+l2*sin(alpha2);
      -l1*cos(alpha1)-l2*cos(alpha2)];

% Zeitabhaengige Variablen als Taylorreihe darstellen
% Die wird gemacht, da Matlab nur explizit ableiten kann
alpha1_ = alpha1 + Dalpha1*t_+0.5*D2alpha1*t_^2;
alpha2_ = alpha2 + Dalpha2*t_+0.5*D2alpha2*t_^2;

% Berechnung der Geschwindigkeit v_i und Beschleunigung a_i, explizites 
% Ableiten nach der Zeit von r_i jetzt moeglich, da die Vektoren explizit
% zeitabhaengig gemacht wurden
r1_h = subs(r1,alpha1,alpha1_);
r1_  = subs(r1_h,alpha2,alpha2_);
r2_h = subs(r2,alpha1,alpha1_);
r2_  = subs(r2_h,alpha2,alpha2_);

% Neu definierte Funktionen, die explizit zeitabhaengig sind, nach t_ abl.
v1_ = diff(r1_,'t_');
v2_ = diff(r2_,'t_');
% das Hilfs-t_=0 setzten, um die nicht relevaten Terme zu loeschen
v1 = subs(v1_,t_,0);
v2 = subs(v2_,t_,0);

% vi_ nochmals explizit nach t_ ableiten, um die Beschleunigung zu erhalten
a1_ = diff(v1_,'t_');
a2_ = diff(v2_,'t_');
% wieder das Hilfs-t_=0 setzten, um die nicht relevaten Terme zu loeschen
a1 = subs(a1_,t_,0);
a2 = subs(a2_,t_,0);

% Jacobi-Matrizen berechnen
Jt1 = jacobian(r1,y);
Jt2 = jacobian(r2,y);

% lokale Beschleunigungen ausrechnen: ai = Jti*ydd+aiq --> aiq = ai-Jti*ydd
a1q = simplify(a1-Jt1*ydd);
a2q = simplify(a2-Jt2*ydd);

% globale Massenmatrix  M_querquer
Mqq = diag([m1 m1 m1 m2 m2 m2]);

% Globale Jacobi-Matrix J_quer
Jq  = [Jt1; 
       Jt2];

% Newton-Euler-Massen-Matrix M_quer berechnen
Mq = Mqq*Jq;

% Vektor der Coriolis-, Zertrifugal- und Kreisel-Kraefte definieren
qc = [m1*a1q; 
      m2*a2q];

% Die eingepraegten Kraefte festlegen
qe = [ 0; 
       0; 
      -m1*g; 
       0; 
       0; 
      -m2*g];

%% D’Alembertsches Prinzip auf Newton-Eulergleichung anwenden
%    Mq*ydd + qc = qe + Qq*g     -->    M*ydd + k = q

% Massenmatrix M resultiert aus Linksmultipli. mit Jq^T & Vereinfachung
M = simplify(Jq.'*Mq)

% Vektor der verallgemeinerten Coriolis- Zertrifugal- Kreisel-Kraefte
k = simplify(Jq.'*qc)

% Vektor der verallgemeinerten eingepraegten-Kraefte
q = simplify(Jq.'*qe)

% Reaktionskraefte verschwinden wegen Orthogonalitaetsbed.: Jq^T*Qq = 0

%% Zusatz-Aufg.: 
% Wie aendert sich die Bewegungsgleichungen, wenn die Daempfung in den 
% Gelenken nicht vernachlaessigt wird?