%% Doppelpendel-Zeitsimulation & Animation
% Simulation: Loesung der nichtlinearen Zustandsdifferentialgleichung

% Anfangsbedingungen:
alpha1_0 = 0*pi/180;
alpha2_0 = 90*pi/180;
x0 = [alpha1_0; alpha2_0; 0; 0];
    
% Randbedingungen:
tspan = [0,5];
    
% Integration der Zustandgleichung:
[t, x] = ode45('beweggl_funktion',tspan,x0);

% Integrationsergebnisse lesen
alpha1_res = x(:,1);
alpha2_res = x(:,2);

% Ergebnisse (Trajektorien) zeichnen
figure(1);
plot(t,[alpha1_res alpha2_res]*180/pi);
title('Trajektorien')
xlabel('Zeit t /sec')
ylabel('Winkel \alpha_1 & \alpha_2 / Grad')

%% Interpolation und Animation der Ergebnisse
dt            = 0.01;                      % Zeitschritt
t_interp      = 0:dt:max(t);
alpha1_interp = interp1(t,alpha1_res,t_interp');
alpha2_interp = interp1(t,alpha2_res,t_interp');

% Werte nochmals definieren
Doppelpendel_Zahlenwerte_init        % Skript mit Definitionen ausfuehren

% Ortsvektoren
r1 = [ 0;
       l1*sin(alpha1_0);
      -l1*cos(alpha1_0)];
r2 = [ 0;
       l1*sin(alpha1_0)+l2*sin(alpha2_0);
      -l1*cos(alpha1_0)-l2*cos(alpha2_0)];

% Anfangskonfiguration zeichnen
h_fig = figure(2); clf;
plot([0 r1(2) r2(2)],[0 r1(3) r2(3)],'-o',...
    'linewidth',2,'markersize',10)

% Zeichenbereich festlegen
axis equal
title('Doppelpendel')
xRange = [-l1-l2 l1+l2]*1.1;
yRange = xRange;
xlim(xRange)
ylim(yRange)
pause(0.5)

% Animation-Schleife durchlaufen
for idx = 1:length(t_interp)
    alpha1_ = alpha1_interp(idx);
    alpha2_  = alpha2_interp(idx);

    % Ortsvektoren aktualisieren
    r1 = [ 0;
           l1*sin(alpha1_);
          -l1*cos(alpha1_)];
    r2 = [ 0;
           l1*sin(alpha1_)+l2*sin(alpha2_);
          -l1*cos(alpha1_)-l2*cos(alpha2_)];

    % Bild neu zeichnen
    figure(h_fig);cla; hold on
    plot([0 r1(2) r2(2)],[0 r1(3) r2(3)],'-o',...
        'linewidth',2,'markersize',10)
    title(sprintf('Simulationszeit: %0.2fs', t_interp(idx)))
    
    % Zeichenbereich festhalten
    pause(0.02)
end % for
